#' ie2miscdata: Irucka Embry's Miscellaneous USGS Data Collection
#'
#' ie2miscdata provides various data sets [USGS Parameter codes with fixed
#'   values, USGS global time zone codes, and US Air Force Global Engineering
#'   Weather Data] created by Irucka Embry while he was a Cherokee Nation
#'   Technology Solutions (CNTS) United States Geological Survey (USGS)
#'   Contractor and/or USGS employee.
#'
#'
#'
#' @keywords internal
"_PACKAGE"
#> [1] "_PACKAGE"
